@@ -1,7 +1,7 @@
 //! Handles all the command arguments and logging
 
 use crate::builder::tokenizer::Token;
-use crate::builder::parser::ast::Rvalue;
+use crate::builder::parser::ast::Prim;
 
 use clap::{ArgMatches, App, Arg};
 use colored::*;
@@ -209,7 +209,7 @@ impl Logger {
         self.set_pos(t.pos);
     }
 
-    pub fn set_rvalue_pos(&mut self, val: &Rvalue) {
+    pub fn set_prim_pos(&mut self, val: &Prim) {
         self.set_line(val.line);
         self.set_pos(val.pos);
     }
